import * as d3 from 'd3';
import { globalSetting } from '../global';

export class ConnectionRender {
    /**
     * @param {d3.Selection} selection
     */
    constructor(selection) {
        this.parentSelection = selection;
        
        /**
         * @type {BasicD3DataItem[]}
         */
        this.data = [];
    }

    /**
     * @description 将 elknode 关于 module connection 的数据添加为 d3 数据项目
     * @param {ElkPort} cellPort 连接点对象
     * @param {ElkNode} node 当前的实体（port/例化模块/器件）
     */
    addAsD3DataItem(cellPort, node) {
        this.data.push({
            x: cellPort.x + node.x,
            y: cellPort.y + node.y + 0.5,       // 0.5 是为了线宽
            width: cellPort.width,
            height: cellPort.height,
            fill: 'var(--main-color)',
            text: '',
            r: 3.5
        });
    }

    render() {
        const data = this.data;

        let connectionSelections = this.parentSelection.selectAll('circle')
            .data(data)
            .enter()
            .append('circle')
            .attr('cx', data => data.x)
            .attr('cy', data => data.y)
            .attr('width', data => data.width)
            .attr('height', data => data.height)
        
        if (globalSetting.renderAnimation) {
            connectionSelections = connectionSelections
                .transition()
                .duration(1000);
        }

        connectionSelections
            .attr('fill', d => d.fill)
            .attr('r', d => d.r);

        this.selections = connectionSelections;
        return connectionSelections;
    }
}
